@@ -1,5 +1,6 @@
 from .lzhw_alg import LZHW, decompress_from_file
 from .lzhw_df import CompressedDF, decompress_df_from_file
 from .huffman_coding import huffman_coding
-from .lz20 import lz20
+#from .lz20 import lz20
+from lz20c import lz20
 from .lz78 import lz78
\ No newline at end of file
