@@ -1,14 +1,14 @@
 from .lzhw_alg import LZHW
 from pickle import dump, load, HIGHEST_PROTOCOL
-from .compress_util import huffman_decode
+from .compress_util import huffman_decode, org_shaping
 import pandas as pd
 from lzw_c import *
 from tqdm import tqdm
 
 class CompressedDF:
-    def __init__(self, df, selected_columns = "all"):
+    def __init__(self, df, selected_cols = "all"):
         self.columns = list(df.columns)
-        if selected_columns == "all":
+        if selected_cols == "all":
             selected = range(df.shape[1])
         else:
             selected = selected_columns
@@ -19,18 +19,27 @@ class CompressedDF:
 
     def save_to_file(self, file):
         with open(file, "wb") as output:
-            dump(lzw_compress(" ".join(self.columns)), output, HIGHEST_PROTOCOL)
+            cols = [i.replace(" ", "__") for i in self.columns]
+            dump(lzw_compress(" ".join(cols)), output, HIGHEST_PROTOCOL)
             for i in range(len(self.columns)):
                 dump(self.compressed[i].compressed, output, HIGHEST_PROTOCOL)
                 dump(self.compressed[i].sequences, output, HIGHEST_PROTOCOL)
 
-def decompress_df_from_file(file):
+def decompress_df_from_file(file, selected_cols = "all"):
     with open(file, "rb") as input:
         cols = load(input)
         cols = lzw_decompress(cols).split()
+        cols = [i.replace("__", " ") for i in cols]
+        if selected_cols == "all":
+            selected = range(len(cols))
+        else:
+            selected = selected_cols
         df = {}
         for i in tqdm(range(len(cols))):
             bit_string = load(input)
             sequences = load(input)
-            df[cols[i]] = " ".join(huffman_decode(sequences, bit_string)).split()
-    return pd.DataFrame(df)
\ No newline at end of file
+            if i in selected:
+                df[cols[i]] = org_shaping(sequences, bit_string)
+            else:
+                continue
+    return pd.DataFrame(df)
